@@ -8,6 +8,9 @@ pub use cluster::ClusterPhase;
 pub use cluster::InvalidIpFamily;
 pub use cluster::*;
 
+pub use controlplane::kubeadm::KubeadmControlPlane;
+pub use infrastructure::aws::AWSCluster;
+
 use crate::errors as capierrors;
 
 pub mod bootstrap;
