@@ -1,18 +1,16 @@
 use std::collections::BTreeMap;
 
-use kube::CustomResource;
-use serde::{Deserialize, Serialize};
-use serde_with::{serde_as, skip_serializing_none};
-
 use super::*;
 
 pub use network::ClassicELBScheme;
 pub use network::NetworkSpec;
 pub use network::NetworkStatus;
+pub use network::VPCSpec;
 pub use tags::Tags;
 pub use types::AZSelectionScheme;
 pub use types::Instance;
 
+mod impls;
 mod network;
 mod tags;
 mod types;
